@@ -6,6 +6,8 @@ from sphinx_click import ext
 
 
 class CommandTestCase(unittest.TestCase):
+    """Validate basic ``click.Command`` instances."""
+
     def test_no_parameters(self):
         """Validate a `click.Command` with no parameters.
 
@@ -19,17 +21,21 @@ class CommandTestCase(unittest.TestCase):
             pass
 
         ctx = click.Context(foobar, info_name='foobar')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command.
 
         .. program:: foobar
         .. code-block:: shell
 
             foobar [OPTIONS]
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
     def test_basic_parameters(self):
         """Validate a combination of parameters.
@@ -40,18 +46,23 @@ class CommandTestCase(unittest.TestCase):
 
         @click.command()
         @click.option('--param', envvar='PARAM', help='A sample option')
-        @click.option('--choice', help='A sample option with choices',
-                      type=click.Choice(['Option1', 'Option2']))
+        @click.option('--another', metavar='[FOO]', help='Another option')
+        @click.option(
+            '--choice',
+            help='A sample option with choices',
+            type=click.Choice(['Option1', 'Option2']),
+        )
         @click.argument('ARG', envvar='ARG')
         def foobar(bar):
             """A sample command."""
             pass
 
         ctx = click.Context(foobar, info_name='foobar')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command.
 
         .. program:: foobar
@@ -65,6 +76,10 @@ class CommandTestCase(unittest.TestCase):
 
             A sample option
 
+        .. option:: --another <FOO>
+
+            Another option
+
         .. option:: --choice <choice>
 
             A sample option with choices
@@ -92,26 +107,68 @@ class CommandTestCase(unittest.TestCase):
            :noindex:
 
             Provide a default for :option:`ARG`
-        """).lstrip(), '\n'.join(output))
-
-    @unittest.skipIf(ext.CLICK_VERSION < (7, 0),
-                     'Allowing show_default to be a string was added in Click 7.0')
-    def test_defaults(self):
-        """Validate formatting of user documented defaults.
         """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
+    def test_help_epilog(self):
+        """Validate formatting of explicit help and epilog strings."""
+
+        @click.command(help='A sample command.', epilog='A sample epilog.')
+        @click.option('--param', help='A sample option')
+        def foobar(bar):
+            pass
+
+        ctx = click.Context(foobar, info_name='foobar')
+        output = list(ext._format_command(ctx, nested='short'))
+
+        self.assertEqual(
+            textwrap.dedent(
+                """
+        A sample command.
+
+        .. program:: foobar
+        .. code-block:: shell
+
+            foobar [OPTIONS]
+
+        .. rubric:: Options
+
+        .. option:: --param <param>
+
+            A sample option
+
+        A sample epilog.
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
+    @unittest.skipIf(
+        ext.CLICK_VERSION < (7, 0),
+        'Allowing show_default to be a string was added in Click 7.0',
+    )
+    def test_defaults(self):
+        """Validate formatting of user documented defaults."""
 
         @click.command()
         @click.option('--num-param', type=int, default=42, show_default=True)
-        @click.option('--param', default=lambda: None, show_default='Something computed at runtime')
+        @click.option(
+            '--param',
+            default=lambda: None,
+            show_default='Something computed at runtime',
+        )
         def foobar(bar):
             """A sample command."""
             pass
 
         ctx = click.Context(foobar, info_name='foobar')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command.
 
         .. program:: foobar
@@ -123,15 +180,19 @@ class CommandTestCase(unittest.TestCase):
 
         .. option:: --num-param <num_param>
 
-            [default: 42]
+            :default: 42
 
         .. option:: --param <param>
 
-            [default: Something computed at runtime]
-        """).lstrip(), '\n'.join(output))
+            :default: Something computed at runtime
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
-    @unittest.skipIf(ext.CLICK_VERSION < (7, 0),
-                     'The hidden flag was added in Click 7.0')
+    @unittest.skipIf(
+        ext.CLICK_VERSION < (7, 0), 'The hidden flag was added in Click 7.0'
+    )
     def test_hidden(self):
         """Validate a `click.Command` with the `hidden` flag."""
 
@@ -141,12 +202,60 @@ class CommandTestCase(unittest.TestCase):
             pass
 
         ctx = click.Context(foobar, info_name='foobar')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual('', '\n'.join(output))
 
+    def test_titles(self):
+        """Validate a `click.Command` with nested titles."""
+
+        @click.command()
+        @click.option('--name', help='Name to say hello to.', required=True, type=str)
+        def hello(name):
+            """Prints hello to name given.
+
+            Examples
+            --------
+
+            .. code:: bash
+
+                my_cli hello --name "Jack"
+            """
+
+        ctx = click.Context(hello, info_name='hello')
+        output = list(ext._format_command(ctx, nested='short'))
+
+        self.assertEqual(
+            textwrap.dedent(
+                """
+        Prints hello to name given.
+
+        Examples
+        --------
+
+        .. code:: bash
+
+            my_cli hello --name "Jack"
+
+        .. program:: hello
+        .. code-block:: shell
+
+            hello [OPTIONS]
+
+        .. rubric:: Options
+
+        .. option:: --name <name>
+
+            **Required** Name to say hello to.
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
 
 class GroupTestCase(unittest.TestCase):
+    """Validate basic ``click.Group`` instances."""
+
     def test_no_parameters(self):
         """Validate a `click.Group` with no parameters.
 
@@ -160,17 +269,21 @@ class GroupTestCase(unittest.TestCase):
             pass
 
         ctx = click.Context(cli, info_name='cli')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
         .. code-block:: shell
 
             cli [OPTIONS] COMMAND [ARGS]...
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
     def test_basic_parameters(self):
         """Validate a combination of parameters.
@@ -187,10 +300,11 @@ class GroupTestCase(unittest.TestCase):
             pass
 
         ctx = click.Context(cli, info_name='cli')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
@@ -225,7 +339,10 @@ class GroupTestCase(unittest.TestCase):
            :noindex:
 
             Provide a default for :option:`ARG`
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
     def test_no_line_wrapping(self):
         r"""Validate behavior when a \b character is present.
@@ -248,10 +365,11 @@ class GroupTestCase(unittest.TestCase):
             pass
 
         ctx = click.Context(cli, info_name='cli')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         | This is
@@ -265,10 +383,15 @@ class GroupTestCase(unittest.TestCase):
         .. code-block:: shell
 
             cli [OPTIONS] COMMAND [ARGS]...
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
 
 class NestedCommandsTestCase(unittest.TestCase):
+    """Validate ``click.Command`` instances inside ``click.Group`` instances."""
+
     @staticmethod
     def _get_ctx():
         @click.group()
@@ -283,17 +406,19 @@ class NestedCommandsTestCase(unittest.TestCase):
 
         return click.Context(cli, info_name='cli')
 
-    def test_hide_nested(self):
-        """Validate a nested command without show_nested.
+    def test_nested_short(self):
+        """Validate a nested command with 'nested' of 'short' (default).
 
-        If we're not showing sub-commands separately, we should list them.
+        We should list minimal help texts for sub-commands since they're not
+        being handled separately.
         """
 
         ctx = self._get_ctx()
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
@@ -306,29 +431,61 @@ class NestedCommandsTestCase(unittest.TestCase):
         .. object:: hello
 
             A sample command.
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
-    def test_show_nested(self):
-        """Validate a nested command with show_nested.
+    def test_nested_full(self):
+        """Validate a nested command with 'nested' of 'full'.
 
-        If we're not showing sub-commands separately, we should not list them.
+        We should not list sub-commands since they're being handled separately.
         """
 
         ctx = self._get_ctx()
-        output = list(ext._format_command(ctx, show_nested=True))
+        output = list(ext._format_command(ctx, nested='full'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
         .. code-block:: shell
 
             cli [OPTIONS] COMMAND [ARGS]...
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
+    def test_nested_none(self):
+        """Validate a nested command with 'nested' of 'none'.
+
+        We should not list sub-commands.
+        """
+
+        ctx = self._get_ctx()
+        output = list(ext._format_command(ctx, nested='none'))
+
+        self.assertEqual(
+            textwrap.dedent(
+                """
+        A sample command group.
+
+        .. program:: cli
+        .. code-block:: shell
+
+            cli [OPTIONS] COMMAND [ARGS]...
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
 
 class CommandFilterTestCase(unittest.TestCase):
+    """Validate filtering of commands."""
+
     @staticmethod
     def _get_ctx():
         @click.group()
@@ -349,27 +506,31 @@ class CommandFilterTestCase(unittest.TestCase):
         """Validate an empty command group."""
 
         ctx = self._get_ctx()
-        output = list(ext._format_command(ctx, show_nested=False, commands=''))
+        output = list(ext._format_command(ctx, nested='short', commands=''))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
         .. code-block:: shell
 
             cli [OPTIONS] COMMAND [ARGS]...
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
     def test_order_of_commands(self):
         """Validate the order of commands."""
 
         ctx = self._get_ctx()
-        output = list(ext._format_command(ctx, show_nested=False,
-                                          commands='world, hello'))
+        output = list(ext._format_command(ctx, nested='short', commands='world, hello'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample command group.
 
         .. program:: cli
@@ -386,10 +547,15 @@ class CommandFilterTestCase(unittest.TestCase):
         .. object:: hello
 
             A sample command.
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
 
 class CustomMultiCommandTestCase(unittest.TestCase):
+    """Validate ``click.MultiCommand`` instances."""
+
     def test_basics(self):
         """Validate a custom ``click.MultiCommand`` with no parameters.
 
@@ -419,10 +585,11 @@ class CustomMultiCommandTestCase(unittest.TestCase):
 
         cli = MyCLI(help='A sample custom multicommand.')
         ctx = click.Context(cli, info_name='cli')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample custom multicommand.
 
         .. program:: cli
@@ -439,12 +606,17 @@ class CustomMultiCommandTestCase(unittest.TestCase):
         .. object:: world
 
             A world command.
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
 
-    @unittest.skipIf(ext.CLICK_VERSION < (7, 0),
-                     'The hidden flag was added in Click 7.0')
+    @unittest.skipIf(
+        ext.CLICK_VERSION < (7, 0), 'The hidden flag was added in Click 7.0'
+    )
     def test_hidden(self):
         """Ensure 'hidden' subcommands are not shown."""
+
         @click.command()
         def hello():
             """A sample command."""
@@ -472,11 +644,12 @@ class CustomMultiCommandTestCase(unittest.TestCase):
 
         cli = MyCLI(help='A sample custom multicommand.')
         ctx = click.Context(cli, info_name='cli')
-        output = list(ext._format_command(ctx, show_nested=False))
+        output = list(ext._format_command(ctx, nested='short'))
 
         # Note that we do NOT expect this to show the 'hidden' command
         self.assertEqual(
-            textwrap.dedent("""
+            textwrap.dedent(
+                """
         A sample custom multicommand.
 
         .. program:: cli
@@ -493,4 +666,7 @@ class CustomMultiCommandTestCase(unittest.TestCase):
         .. object:: world
 
             A world command.
-        """).lstrip(), '\n'.join(output))
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
